@@ -56,10 +56,10 @@ def flash(msg, css_class='warning'):
 class Controller(object):
     def __init__(self, application, template_path, helpers):
         self.template_path = template_path
-        self.loader = ArtichokeTemplateLoader(template_path)
+        self.application = application
+        self.loader = ArtichokeTemplateLoader(template_path, self.application.minify_templates)
         self.helpers = helpers
         self.templates = {}
-        self.application = application
 
     def render(self, template, params):
         if not self.application.autoreload_templates:
@@ -69,7 +69,7 @@ class Controller(object):
                 tmpl = self.loader.load(template)
                 self.templates[template] = tmpl
         else:
-            self.loader = ArtichokeTemplateLoader(self.template_path)
+            self.loader = ArtichokeTemplateLoader(self.template_path, self.application.minify_templates)
             tmpl = self.loader.load(template)
 
         return tmpl.render(params)
