@@ -1,5 +1,3 @@
-import genshi
-
 class FormBuilder(object):
     def __init__(self, action, fields, fields_order=None):
         self.fields = fields
@@ -35,4 +33,4 @@ class FormBuilder(object):
                 </tr>\n'''
         form += '</table>\n'
         form += '</form>\n'
-        return genshi.Markup(form)
+        return form
