@@ -120,12 +120,11 @@ def main(main_func, args=None, kwargs=None):
 
 def serve(app):
     #This is here just to create a simple WSGI server for development environment
-    from wsgiref.util import setup_testing_defaults
     from wsgiref.simple_server import make_server
     app.autoreload_templates = True
 
     def reloaded_main():
-        httpd = make_server('', 8080, app)
+        httpd = make_server('0.0.0.0', 8080, app)
         print "Artichoke Serving on port 8080..."
         httpd.serve_forever()
 
