@@ -34,6 +34,9 @@ class ArtichokeTemplate(object):
     def _parsed(self):
         padding = ''
         for line in self.text.split('\n'):
+            if not self.minify:
+                line += '\\n'
+
             for linepart, piece in enumerate(re.split(r'\$\{(.*?)\}', line)):
                 if self.minify:
                     piece = piece.strip()
@@ -97,8 +100,9 @@ class ArtichokeTemplate(object):
         return u''.join(globals['__output__']).encode('utf-8')
 
 class ArtichokeTemplateLoader(object):
-    def __init__(self, path):
+    def __init__(self, path, minify=False):
         self.path = path
+        self.minify = minify
 
     def load(self, tmpl):
         if not tmpl.endswith('choke'):
@@ -106,7 +110,7 @@ class ArtichokeTemplateLoader(object):
 
         f = open(os.path.join(self.path, tmpl))
         try:
-            tmpl = ArtichokeTemplate(f.read())
+            tmpl = ArtichokeTemplate(f.read(), self.minify)
             tmpl._compile()
             return tmpl
         finally:
